/*!
Hex Graph. The submodules are for different Coodinate representations of Hex Graph.
*/

pub mod axial_based;
pub mod double_coord;
#[cfg(feature = "hex2d")]
pub mod hex2d;
pub mod offset_based;
pub mod shapes;
